aboutsummaryrefslogtreecommitdiffstats
path: root/contrib/libs/ngtcp2/lib/ngtcp2_addr.h
diff options
context:
space:
mode:
authorrobot-contrib <robot-contrib@yandex-team.com>2025-03-10 19:42:22 +0300
committerrobot-contrib <robot-contrib@yandex-team.com>2025-03-10 19:56:23 +0300
commitfc6cd7d48282fba73b60215b3fd31fc0a8825982 (patch)
treebcb36b06098e700fd726b6b19c89e6fae7d429e2 /contrib/libs/ngtcp2/lib/ngtcp2_addr.h
parent21c1cc59ef7d0910313ef39ca737c78380ef3ec3 (diff)
downloadydb-fc6cd7d48282fba73b60215b3fd31fc0a8825982.tar.gz
Update contrib/libs/ngtcp2 to 1.11.0
commit_hash:3beea54841aa142a4af33f802d5bdb7d6010b68d
Diffstat (limited to 'contrib/libs/ngtcp2/lib/ngtcp2_addr.h')
-rw-r--r--contrib/libs/ngtcp2/lib/ngtcp2_addr.h30
1 files changed, 18 insertions, 12 deletions
diff --git a/contrib/libs/ngtcp2/lib/ngtcp2_addr.h b/contrib/libs/ngtcp2/lib/ngtcp2_addr.h
index 65ee7cd9f3..c2224f85cd 100644
--- a/contrib/libs/ngtcp2/lib/ngtcp2_addr.h
+++ b/contrib/libs/ngtcp2/lib/ngtcp2_addr.h
@@ -45,22 +45,21 @@ void ngtcp2_addr_copy(ngtcp2_addr *dest, const ngtcp2_addr *src);
*/
int ngtcp2_addr_eq(const ngtcp2_addr *a, const ngtcp2_addr *b);
-/* NGTCP2_ADDR_COMPARE_FLAG_NONE indicates that no flag set. */
-#define NGTCP2_ADDR_COMPARE_FLAG_NONE 0x0u
-/* NGTCP2_ADDR_COMPARE_FLAG_ADDR indicates IP addresses do not
+/* NGTCP2_ADDR_CMP_FLAG_NONE indicates that no flag set. */
+#define NGTCP2_ADDR_CMP_FLAG_NONE 0x0u
+/* NGTCP2_ADDR_CMP_FLAG_ADDR indicates IP addresses do not match. */
+#define NGTCP2_ADDR_CMP_FLAG_ADDR 0x1u
+/* NGTCP2_ADDR_CMP_FLAG_PORT indicates ports do not match. */
+#define NGTCP2_ADDR_CMP_FLAG_PORT 0x2u
+/* NGTCP2_ADDR_CMP_FLAG_FAMILY indicates address families do not
match. */
-#define NGTCP2_ADDR_COMPARE_FLAG_ADDR 0x1u
-/* NGTCP2_ADDR_COMPARE_FLAG_PORT indicates ports do not match. */
-#define NGTCP2_ADDR_COMPARE_FLAG_PORT 0x2u
-/* NGTCP2_ADDR_COMPARE_FLAG_FAMILY indicates address families do not
- match. */
-#define NGTCP2_ADDR_COMPARE_FLAG_FAMILY 0x4u
+#define NGTCP2_ADDR_CMP_FLAG_FAMILY 0x4u
/*
* ngtcp2_addr_compare compares address and port between |a| and |b|,
* and returns zero or more of NGTCP2_ADDR_COMPARE_FLAG_*.
*/
-uint32_t ngtcp2_addr_compare(const ngtcp2_addr *a, const ngtcp2_addr *b);
+uint32_t ngtcp2_addr_cmp(const ngtcp2_addr *a, const ngtcp2_addr *b);
/*
* ngtcp2_addr_empty returns nonzero if |addr| has zero length
@@ -68,4 +67,11 @@ uint32_t ngtcp2_addr_compare(const ngtcp2_addr *a, const ngtcp2_addr *b);
*/
int ngtcp2_addr_empty(const ngtcp2_addr *addr);
+/**
+ * @function
+ *
+ * `ngtcp2_sockaddr_eq` returns nonzero if |a| equals |b|.
+ */
+int ngtcp2_sockaddr_eq(const ngtcp2_sockaddr *a, const ngtcp2_sockaddr *b);
+
#endif /* !defined(NGTCP2_ADDR_H) */
@@ -45,22 +45,21 @@ void ngtcp2_addr_copy(ngtcp2_addr *dest, const ngtcp2_addr *src);
/*
- * ngtcp2_addr_compare compares address and port between |a| and |b|,
- * and returns zero or more of NGTCP2_ADDR_COMPARE_FLAG_*.
+ * ngtcp2_addr_cmp compares address and port between |a| and |b|, and
+ * returns zero or more of NGTCP2_ADDR_CMP_FLAG_*.
*/